@@ -367,6 +367,12 @@ QT_CHARTS_BEGIN_NAMESPACE
   This signal is emitted when the angle of the axis labels changes to \a angle.
 */
 
+/*!
+  \fn void QAbstractAxis::labelsEditableChanged(bool editable)
+  \since 5.13
+  This signal is emitted when the \a editable state of the label changes.
+*/
+
 /*!
   \fn void QAbstractAxis::gridVisibleChanged(bool visible)
   This signal is emitted when the visibility of the grid lines of the axis changes to \a visible.
@@ -948,6 +954,39 @@ bool QAbstractAxis::isReverse() const
     return d_ptr->m_reverse;
 }
 
+/*!
+  Sets axis labels editability to \a editable.
+
+  When the labels are editable the user will be able to change the range of the
+  axis conveniently by editing any of the labels. This feature is only supported
+  for the QValueAxis and the QDateTimeAxis.
+
+  By default, labels are not editable.
+  \since 5.13
+*/
+void QAbstractAxis::setLabelsEditable(bool editable)
+{
+    if (d_ptr->m_labelsEditable != editable) {
+        // In the case if the axis already added to a chart
+        // set the labels editability on the axisItem().
+        // Otherwise the labels editability will be set in the
+        // QValueAxisPrivate::initializeGraphics.
+        if (d_ptr->axisItem() != nullptr)
+            d_ptr->axisItem()->setLabelsEditable(editable);
+        d_ptr->m_labelsEditable = editable;
+        emit labelsEditableChanged(editable);
+    }
+}
+
+/*!
+  Returns \c true if axis labels are editable.
+  \since 5.13
+*/
+bool QAbstractAxis::labelsEditable() const
+{
+    return d_ptr->m_labelsEditable;
+}
+
 void QAbstractAxis::setReverse(bool reverse)
 {
     if (d_ptr->m_reverse != reverse && type() != QAbstractAxis::AxisTypeBarCategory) {
@@ -960,30 +999,16 @@ void QAbstractAxis::setReverse(bool reverse)
 
 QAbstractAxisPrivate::QAbstractAxisPrivate(QAbstractAxis *q)
     : q_ptr(q),
-      m_chart(0),
-      m_alignment(0),
-      m_orientation(Qt::Orientation(0)),
-      m_visible(true),
-      m_arrowVisible(true),
       m_axisPen(QChartPrivate::defaultPen()),
       m_axisBrush(QChartPrivate::defaultBrush()),
-      m_gridLineVisible(true),
       m_gridLinePen(QChartPrivate::defaultPen()),
-      m_minorGridLineVisible(true),
       m_minorGridLinePen(QChartPrivate::defaultPen()),
-      m_labelsVisible(true),
       m_labelsBrush(QChartPrivate::defaultBrush()),
       m_labelsFont(QChartPrivate::defaultFont()),
-      m_labelsAngle(0),
-      m_titleVisible(true),
       m_titleBrush(QChartPrivate::defaultBrush()),
       m_titleFont(QChartPrivate::defaultFont()),
-      m_shadesVisible(false),
       m_shadesPen(QChartPrivate::defaultPen()),
-      m_shadesBrush(QChartPrivate::defaultBrush()),
-      m_shadesOpacity(1.0),
-      m_dirty(false),
-      m_reverse(false)
+      m_shadesBrush(QChartPrivate::defaultBrush())
 {
 }
 
